==> kvirc_3.2.0.orig.tar.gz: kvirc-3.2.0/src/kvirc/ui/kvi_msgbox.h <==
#ifndef _KVI_MSGBOX_H_
#define _KVI_MSGBOX_H_

//
//   File : kvi_msgbox.h
//   Creation date : Sun Jan 17 1999 13:55:41 by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 1999-2000 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_settings.h"
#include "kvi_qstring.h"
/*
class KviMessageBox : public KviTalMessageBox
{
	enum Result { Yes , No , Ok , Cancel };
	enum ButtonResult { Button1 , Button2 , Button3 };

	KVIRC_API void warning(const char * fmt,...);
	KVIRC_API void information(const char * fmt,...);

	KVIRC_API Result yesNo(const char * fmt,...);
	KVIRC_API Result yesNoCancel(const char * fmt,...);

	KVIRC_API ButtonResult oneButton(const char * btnTxt,const char * fmt,...);
	KVIRC_API ButtonResult twoButtons(const char * btnTxt1,const char * btnTxt2,const char * fmt,...);
	KVIRC_API ButtonResult threeButtons(const char * btnTxt1,const char * btnTxt2,const char * btnTxt3,const char * fmt,...);
};
*/

namespace KviMessageBox
{
	KVIRC_API void warning(const QString &fmt,...);
};

extern KVIRC_API void kvi_warningBox(const char * fmt,...);
extern KVIRC_API void kvi_infoBox(const char * caption,const char * fmt,...);
extern KVIRC_API bool kvi_yesNo(const char * caption,const char * fmt,...);

#endif //!_KVI_MSGBOX_H_

==> kvirc_3.4.0.orig.tar.gz: kvirc-3.4.0/src/kvirc/ui/kvi_msgbox.h <==
#ifndef _KVI_MSGBOX_H_
#define _KVI_MSGBOX_H_

//
//   File : kvi_msgbox.h
//   Creation date : Sun Jan 17 1999 13:55:41 by Szymon Stefanek
//
//   This file is part of the KVirc irc client distribution
//   Copyright (C) 1999-2000 Szymon Stefanek (pragma at kvirc dot net)
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc. ,59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#include "kvi_settings.h"
#include "kvi_qstring.h"
/*
class KviMessageBox : public KviTalMessageBox
{
	enum Result { Yes , No , Ok , Cancel };
	enum ButtonResult { Button1 , Button2 , Button3 };

	KVIRC_API void warning(const char * fmt,...);
	KVIRC_API void information(const char * fmt,...);

	KVIRC_API Result yesNo(const char * fmt,...);
	KVIRC_API Result yesNoCancel(const char * fmt,...);

	KVIRC_API ButtonResult oneButton(const char * btnTxt,const char * fmt,...);
	KVIRC_API ButtonResult twoButtons(const char * btnTxt1,const char * btnTxt2,const char * fmt,...);
	KVIRC_API ButtonResult threeButtons(const char * btnTxt1,const char * btnTxt2,const char * btnTxt3,const char * fmt,...);
};
*/

namespace KviMessageBox
{
	KVIRC_API void warning(const QString &fmt,...);
	KVIRC_API void information(const QString &fmt,...);
	KVIRC_API bool yesNo(const QString &caption,const QString &fmt,...);
};

#endif //!_KVI_MSGBOX_H_
